==> fantacalciobazar_0.4.tar.gz: fantacalciobazar/vendi.php <==
<?php

##################################################################################
#    FANTACALCIOBAZAR
#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##################################################################################


include("controlla_pass.php");
include("$percorso_cartella_dati/head.php");
if ($pass_errata != "SI") {



$trovato = "NO";
$num_calciatori_posseduti = 0;
$soldi_spesi = 0;
$calciatori = file("$percorso_cartella_dati/mercato.txt");
$num_calciatori = count($calciatori);
for ($num1 = 0 ; $num1 < $num_calciatori ; $num1++) {
$dati_calciatore = explode(",", $calciatori[$num1]);
$numero = $dati_calciatore[0];
$proprietario = $dati_calciatore[4];
if ($proprietario == $nome_utente) {
$soldi_spesi = $soldi_spesi + $dati_calciatore[3];
$num_calciatori_posseduti++;

if ($num_calciatore == $numero) {
$nome = $dati_calciatore[1];
$ruolo = $dati_calciatore[2];
$costo = $dati_calciatore[3];
$tempo_off = $dati_calciatore[5];
$anno_off = substr($tempo_off,0,4);
$mese_off = substr($tempo_off,4,2);
$giorno_off = substr($tempo_off,6,2);
$ora_off = substr($tempo_off,8,2);
$minuto_off = substr($tempo_off,10,2);
$adesso = mktime(date("H"),date("i"),0,date("m"),date("d"),date("Y"));
$sec_restanti = mktime($ora_off,$minuto_off,0,$mese_off,$giorno_off,$anno_off) - $adesso;
if ($sec_restanti < 0) { $trovato = "SI"; }
} # fine if ($num_calciatore == $numero)
} # fine if ($proprietario == $nome_utente)
} # fine for $num1

if ($trovato == "NO") {
echo "Non puoi vendere questo calciatore.<br>";
} # fine if ($trovato == "NO")

else {
if ($stato_mercato == "S") echo "<center>Il mercato  <b>sospeso</b> in questo momento.</center><br>";
if ($stato_mercato == "C") echo "<center>Il mercato  <b>chiuso</b> in questo momento.</center><br>";
else {
$prezzo_vendita = floor(($costo/100)*$percentuale_vendita);
echo "<form method=\"post\" action=\"vendi_subito.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"hidden\" name=\"num_calciatore\" value=\"$num_calciatore\">
<input type=\"submit\" name=\"vendi_subito\" value=\"Vendi subito\">
 il calciatore <b>$nome</b> per <b>$prezzo_vendita</b> Fanta-Euro (comprato a <b>$costo</b> Fanta-Euro).<br>
</form>";
if ($stato_mercato != "S") {
echo "<form method=\"post\" action=\"vendi_sul_mercato.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"hidden\" name=\"num_calciatore\" value=\"$num_calciatore\">
<input type=\"submit\" name=\"rivendi\" value=\"Rimetti sul mercato\">
 il calciatore <b>$nome</b> per almeno
<input type=\"text\" name=\"valore_rivendita\" size=\"8\">  Fanta-Euro.<br>
</form>";
} # fine if ($stato_mercato != "S")
} # fine else if ($stato_mercato == "C")
} # fine else if ($trovato == "NO")

echo "<center><form method=\"post\" action=\"squadra.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"hidden\" name=\"nome_squadra\" value=\"$nome_utente\">
<input type=\"submit\" name=\"torna_squadra\" value=\"Torna alla squadra\">
</form></center>";



} # fine if ($pass_errata != "SI")

include("$percorso_cartella_dati/foot.php");
?>

==> fantacalciobazar_0.5.1.tar.gz: fantacalciobazar/vendi.php <==
<?php

##################################################################################
#    FANTACALCIOBAZAR
#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##################################################################################


include("./controlla_pass.php");
include("$percorso_cartella_dati/head.php");
if ($pass_errata != "SI") {



$trovato = "NO";
$num_calciatori_posseduti = 0;
$soldi_spesi = 0;
$calciatori = file("$percorso_cartella_dati/mercato.txt");
$num_calciatori = count($calciatori);
for ($num1 = 0 ; $num1 < $num_calciatori ; $num1++) {
$dati_calciatore = explode(",", $calciatori[$num1]);
$numero = $dati_calciatore[0];
$proprietario = $dati_calciatore[4];
if ($proprietario == $nome_utente) {
$soldi_spesi = $soldi_spesi + $dati_calciatore[3];
$num_calciatori_posseduti++;

if ($num_calciatore == $numero) {
$nome = $dati_calciatore[1];
$ruolo = $dati_calciatore[2];
$costo = $dati_calciatore[3];
$tempo_off = $dati_calciatore[5];
$anno_off = substr($tempo_off,0,4);
$mese_off = substr($tempo_off,4,2);
$giorno_off = substr($tempo_off,6,2);
$ora_off = substr($tempo_off,8,2);
$minuto_off = substr($tempo_off,10,2);
$adesso = mktime(date("H"),date("i"),0,date("m"),date("d"),date("Y"));
$sec_restanti = mktime($ora_off,$minuto_off,0,$mese_off,$giorno_off,$anno_off) - $adesso;
if ($sec_restanti < 0) { $trovato = "SI"; }
} # fine if ($num_calciatore == $numero)
} # fine if ($proprietario == $nome_utente)
} # fine for $num1

if ($trovato == "NO") {
echo "Non puoi vendere questo calciatore.<br>";
} # fine if ($trovato == "NO")

else {
if ($stato_mercato == "S") echo "<center>Il mercato  <b>sospeso</b> in questo momento.</center><br>";
if ($stato_mercato == "C") echo "<center>Il mercato  <b>chiuso</b> in questo momento.</center><br>";
else {
$prezzo_vendita = floor(($costo/100)*$percentuale_vendita);
echo "<form method=\"post\" action=\"vendi_subito.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"hidden\" name=\"num_calciatore\" value=\"$num_calciatore\">
<input type=\"submit\" name=\"vendi_subito\" value=\"Vendi subito\">
 il calciatore <b>$nome</b> per <b>$prezzo_vendita</b> Fanta-Euro (comprato a <b>$costo</b> Fanta-Euro).<br>
</form>";
if ($stato_mercato != "S") {
echo "<form method=\"post\" action=\"vendi_sul_mercato.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"hidden\" name=\"num_calciatore\" value=\"$num_calciatore\">
<input type=\"submit\" name=\"rivendi\" value=\"Rimetti sul mercato\">
 il calciatore <b>$nome</b> per almeno
<input type=\"text\" name=\"valore_rivendita\" size=\"8\">  Fanta-Euro.<br>
</form>";
} # fine if ($stato_mercato != "S")
} # fine else if ($stato_mercato == "C")
} # fine else if ($trovato == "NO")

echo "<center><form method=\"post\" action=\"squadra.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"hidden\" name=\"nome_squadra\" value=\"$nome_utente\">
<input type=\"submit\" name=\"torna_squadra\" value=\"Torna alla squadra\">
</form></center>";



} # fine if ($pass_errata != "SI")

include("$percorso_cartella_dati/foot.php");
?>
